#!/usr/bin/env python

import numpy as np
import matplotlib.pyplot as plt
import math


# dist, lcurv(i)*t_ref, pressure, rhom*rho_ref, 1d-5*sqrt(c2)*Req/t_ref

if __name__ == "__main__":
    a = np.loadtxt("profiles")
    cnst = np.max(np.abs(a[:,2]))
    a[:,2] /= -cnst

    fig, ax = plt.subplots(3,3,sharex="col",sharey="row",figsize=(12,6))
    plt.subplots_adjust(hspace=0.0,wspace=0.0)

    nstop = 2000
    ax[0,0].plot(a[:,0],a[:,4],"k-",zorder=2)
    ax[1,0].semilogy(a[:,0],a[:,3],"k-",zorder=2)
    ax[2,0].plot(a[:,0],a[:,2],"k-",zorder=2)
    ax[0,1].plot(a[:nstop,0],a[:nstop,4],"k-",zorder=2)
    ax[1,1].semilogy(a[:nstop,0],a[:nstop,3],"k-",zorder=2)
    ax[2,1].plot(a[:nstop,0],a[:nstop,2],"k-",zorder=2)
    ax[0,2].plot(a[:,1],a[:,4],"k-",zorder=2)
    ax[1,2].semilogy(a[:,1],a[:,3],"k-",zorder=2)
    ax[2,2].plot(a[:,1],a[:,2],"k-",zorder=2)
    ax[2,2].plot(a[:,1],np.sin(21.0*math.pi*a[:,1]/a[-1,1]),"k:",zorder=2)
   
    ndisc = 1253
    xdisc = a[ndisc,0]
    xdisc2 = a[-1,0]-xdisc
    taudisc = a[ndisc,1]
    taudisc2 = a[-1,1]-taudisc

    neq = a.shape[0]//2
    xeq = a[neq,0]
    taueq = a[neq,1]
    for i in range(3):
        ylim = ax[i,0].get_ylim()
        ax[i,0].plot([xdisc,xdisc],ylim,"c-",zorder=1)
        ax[i,0].plot([xdisc2,xdisc2],ylim,"c-",zorder=1)
        ax[i,0].plot([xeq,xeq],ylim,"c:",zorder=1)
        ax[i,1].plot([xdisc,xdisc],ylim,"c-",zorder=1)
        ax[i,2].plot([taudisc,taudisc],ylim,"c-",zorder=1)
        ax[i,2].plot([taudisc2,taudisc2],ylim,"c-",zorder=1)
        ax[i,2].plot([taueq,taueq],ylim,"c:",zorder=1)
        ax[i,0].set_ylim(ylim)

    fontsize=20
    ax[0,0].set_ylabel(r"$c_0$ (km/s)",fontsize=fontsize)
    ax[1,0].set_ylabel(r"$\rho_0$ (g/cm$^3$)",fontsize=fontsize)
    ax[2,0].set_ylabel(r"$\delta P/\sqrt{P_0}$",fontsize=fontsize)
    ax[2,0].set_xlabel(r"Distance, $x/R_{\mathrm{eq}}$",fontsize=fontsize)
    ax[2,1].set_xlabel(r"Distance, $x/R_{\mathrm{eq}}$",fontsize=fontsize)
    ax[2,2].set_xlabel(r"Acoustic travel time, $\tau$ (s)",fontsize=fontsize)

    plt.savefig("profiles.eps")
